setwd("C:/user/GUIDO/LEHRE/GemischteModelle/Datenstze")
boys <- read.table("Boys.txt", header=TRUE)
library(nlme)
# Independence
ind1 <- gls(Length  ~ 1 + Time, data=boys)
ind2 <- lm(Length  ~ 1 + Time, data=boys)
# Compound Symmetry
cs1 <- gls(Length  ~ 1 + Time, data=boys, correlation = corCompSymm(form = ~1|Boy))
# AR(1)
ar1 <- gls(Length  ~ 1 + Time, data=boys, correlation = corAR1(form = ~1|Boy))
# ARMA(1,1)
arma11 <- gls(Length  ~ 1 + Time, data=boys, correlation = corARMA(form = ~1|Boy, p=1, q=1) )
# General Symmetry
gs1 <- gls(Length  ~ 1 + Time, data=boys, correlation = corSymm(form = ~1|Boy))
# Modellvergleich
AIC(ind1, cs1, ar1, arma11, gs1)
#
#
# Marginale Kovarianz- bzw. Korrelationsmatrix im Compound Symmetry Modell
cs1.vcov <- getVarCov(cs1)
print(cs1.vcov)
print(cov2cor(cs1.vcov), corr=TRUE, stdevs=FALSE)
#
#
# Likelihood-Quotienten-Test: Independence vs. Compound Symmetry
anova(ind1, cs1)
# Compound Symmetry vs. AR(1) (nicht-hierachisch)
anova(cs1, ar1)
# LQ-Test: AR(1) vs. ARMA(1,1)
anova(ar1, arma11)
# LQ-Test: Compound Symmetry vs. ARMA(1,1)
anova(cs1, arma11)
# LQ-Test: Compound Symmetry vs. General Symmetry
anova(cs1, gs1)

library(lme4)
# RI Modell
ri1 <- lmer(Length ~ 1 + Time + (1|Boy), data=boys, REML=FALSE)
# RIAS Modell
rias1 <- lmer(Length ~ 1 + Time + (1 + Time|Boy), data=boys, REML=FALSE)
rias2 <- lmer(Length ~ 1 + I(Time-8) + (1 + I(Time - 8)|Boy), data=boys, REML=FALSE)
# Modellvergleich
anova(ri1,rias1)
# Korrelation der zufligen Effekte
summary(rias1)
# REML-Schtzung im RI Modell
ri2 <- update(ri1, REML=TRUE)
summary(ri2)
confint(ri2)
# Ignorieren der Korrelation der zuflligen Effekte im RIAS Modell
# Nicht sinnvoll bei diesem einfachen Modell fr Longitudinaldaten
rias2 <- lmer(Length ~ 1 + Time + (1|Boy) + (0 + Time|Boy), data=boys, REML=FALSE)
summary(rias2)
anova(rias2, rias1)



# OLS = GLS
coef(ind1)
coef(cs1)
coef(ar1)

# Generalized estimating equations 
library(gee)
gee1 <- gee(Length  ~ 1 + Time, data=boys, family = "gaussian", id = Boy, corstr = "independence")
summary(ind1)
summary(gee1)
gee2 <- gee(Length  ~ 1 + Time, data=boys, family = "gaussian", id = Boy, corstr = "exchangeable")
summary(cs1)
summary(gee2)
gee3 <- gee(Length  ~ 1 + Time, data=boys, family = "gaussian", id = Boy, corstr = "AR-M", Mv = 1)
summary(ar1)
summary(gee3)
gee4 <- gee(Length  ~ 1 + Time, data=boys, family = "gaussian", id = Boy, corstr = "unstructured")
summary(gs1)
summary(gee4)


library(geepack)
geepack1 <- geeglm(Length  ~ 1 + Time, data=boys, family = "gaussian", id = Boy, corstr = "independence")
summary(gee1)
summary(geepack1)
geepack2 <- geeglm(Length  ~ 1 + Time, data=boys, family = "gaussian", id = Boy, corstr = "exchangeable")
summary(gee2)
summary(geepack2)
geepack3 <- geeglm(Length  ~ 1 + Time, data=boys, family = "gaussian", id = Boy, corstr = "ar1")
summary(gee3)
summary(geepack3)



geepack4 <- geeglm(Length  ~ 1 + Time, data=boys, family = "gaussian", id = Boy, corstr = "exchangeable", std.err="fij")
geepack5 <- geeglm(Length  ~ 1 + Time, data=boys, family = "gaussian", id = Boy, corstr = "exchangeable", std.err="jack")
geepack6 <- geeglm(Length  ~ 1 + Time, data=boys, family = "gaussian", id = Boy, corstr = "exchangeable", std.err="j1s")
